# coding: utf-8

"""
    Asteroid Agents API

    Version 1 of the Asteroid Agents API

    The version of the OpenAPI document: v1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class CountryCode(str, Enum):
    """
    Two-letter country code for proxy location
    """

    """
    allowed enum values
    """
    US = 'us'
    UK = 'uk'
    FR = 'fr'
    IT = 'it'
    JP = 'jp'
    AU = 'au'
    DE = 'de'
    FI = 'fi'
    CA = 'ca'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of CountryCode from a JSON string"""
        return cls(json.loads(json_str))


