# coding: utf-8

"""
    Agent Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class AgentsExecutionStatus(str, Enum):
    """
    AgentsExecutionStatus
    """

    """
    allowed enum values
    """
    STARTING = 'starting'
    RUNNING = 'running'
    PAUSED = 'paused'
    AWAITING_CONFIRMATION = 'awaiting_confirmation'
    COMPLETED = 'completed'
    CANCELLED = 'cancelled'
    FAILED = 'failed'
    PAUSED_BY_AGENT = 'paused_by_agent'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of AgentsExecutionStatus from a JSON string"""
        return cls(json.loads(json_str))


